==> types_boto3_full-1.35.90.tar.gz: types_boto3_full-1.35.90/types_boto3_sagemaker_edge/type_defs.py <==
"""
Type annotations for sagemaker-edge service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_edge/type_defs/)

Usage::

    ```python
    from types_boto3_sagemaker_edge.type_defs import ChecksumTypeDef

    data: ChecksumTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Sequence, Union

from .literals import DeploymentStatusType, FailureHandlingPolicyType, ModelStateType

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "ChecksumTypeDef",
    "DefinitionTypeDef",
    "DeploymentModelTypeDef",
    "DeploymentResultTypeDef",
    "EdgeDeploymentTypeDef",
    "EdgeMetricTypeDef",
    "EmptyResponseMetadataTypeDef",
    "GetDeploymentsRequestRequestTypeDef",
    "GetDeploymentsResultTypeDef",
    "GetDeviceRegistrationRequestRequestTypeDef",
    "GetDeviceRegistrationResultTypeDef",
    "ModelTypeDef",
    "ResponseMetadataTypeDef",
    "SendHeartbeatRequestRequestTypeDef",
    "TimestampTypeDef",
)

ChecksumTypeDef = TypedDict(
    "ChecksumTypeDef",
    {
        "Type": NotRequired[Literal["SHA1"]],
        "Sum": NotRequired[str],
    },
)


class DeploymentModelTypeDef(TypedDict):
    ModelHandle: NotRequired[str]
    ModelName: NotRequired[str]
    ModelVersion: NotRequired[str]
    DesiredState: NotRequired[ModelStateType]
    State: NotRequired[ModelStateType]
    Status: NotRequired[DeploymentStatusType]
    StatusReason: NotRequired[str]
    RollbackFailureReason: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class GetDeploymentsRequestRequestTypeDef(TypedDict):
    DeviceName: str
    DeviceFleetName: str


class GetDeviceRegistrationRequestRequestTypeDef(TypedDict):
    DeviceName: str
    DeviceFleetName: str


class DefinitionTypeDef(TypedDict):
    ModelHandle: NotRequired[str]
    S3Url: NotRequired[str]
    Checksum: NotRequired[ChecksumTypeDef]
    State: NotRequired[ModelStateType]


class DeploymentResultTypeDef(TypedDict):
    DeploymentName: NotRequired[str]
    DeploymentStatus: NotRequired[str]
    DeploymentStatusMessage: NotRequired[str]
    DeploymentStartTime: NotRequired[TimestampTypeDef]
    DeploymentEndTime: NotRequired[TimestampTypeDef]
    DeploymentModels: NotRequired[Sequence[DeploymentModelTypeDef]]


class EdgeMetricTypeDef(TypedDict):
    Dimension: NotRequired[str]
    MetricName: NotRequired[str]
    Value: NotRequired[float]
    Timestamp: NotRequired[TimestampTypeDef]


class EmptyResponseMetadataTypeDef(TypedDict):
    ResponseMetadata: ResponseMetadataTypeDef


class GetDeviceRegistrationResultTypeDef(TypedDict):
    DeviceRegistration: str
    CacheTTL: str
    ResponseMetadata: ResponseMetadataTypeDef


EdgeDeploymentTypeDef = TypedDict(
    "EdgeDeploymentTypeDef",
    {
        "DeploymentName": NotRequired[str],
        "Type": NotRequired[Literal["Model"]],
        "FailureHandlingPolicy": NotRequired[FailureHandlingPolicyType],
        "Definitions": NotRequired[list[DefinitionTypeDef]],
    },
)


class ModelTypeDef(TypedDict):
    ModelName: NotRequired[str]
    ModelVersion: NotRequired[str]
    LatestSampleTime: NotRequired[TimestampTypeDef]
    LatestInference: NotRequired[TimestampTypeDef]
    ModelMetrics: NotRequired[Sequence[EdgeMetricTypeDef]]


class GetDeploymentsResultTypeDef(TypedDict):
    Deployments: list[EdgeDeploymentTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class SendHeartbeatRequestRequestTypeDef(TypedDict):
    AgentVersion: str
    DeviceName: str
    DeviceFleetName: str
    AgentMetrics: NotRequired[Sequence[EdgeMetricTypeDef]]
    Models: NotRequired[Sequence[ModelTypeDef]]
    DeploymentResult: NotRequired[DeploymentResultTypeDef]

==> types_boto3_full-1.36.0.tar.gz: types_boto3_full-1.36.0/types_boto3_sagemaker_edge/type_defs.py <==
"""
Type annotations for sagemaker-edge service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_edge/type_defs/)

Usage::

    ```python
    from types_boto3_sagemaker_edge.type_defs import ChecksumTypeDef

    data: ChecksumTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import DeploymentStatusType, FailureHandlingPolicyType, ModelStateType

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Sequence
else:
    from typing import Dict, List, Sequence
if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "ChecksumTypeDef",
    "DefinitionTypeDef",
    "DeploymentModelTypeDef",
    "DeploymentResultTypeDef",
    "EdgeDeploymentTypeDef",
    "EdgeMetricTypeDef",
    "EmptyResponseMetadataTypeDef",
    "GetDeploymentsRequestRequestTypeDef",
    "GetDeploymentsResultTypeDef",
    "GetDeviceRegistrationRequestRequestTypeDef",
    "GetDeviceRegistrationResultTypeDef",
    "ModelTypeDef",
    "ResponseMetadataTypeDef",
    "SendHeartbeatRequestRequestTypeDef",
    "TimestampTypeDef",
)

ChecksumTypeDef = TypedDict(
    "ChecksumTypeDef",
    {
        "Type": NotRequired[Literal["SHA1"]],
        "Sum": NotRequired[str],
    },
)


class DeploymentModelTypeDef(TypedDict):
    ModelHandle: NotRequired[str]
    ModelName: NotRequired[str]
    ModelVersion: NotRequired[str]
    DesiredState: NotRequired[ModelStateType]
    State: NotRequired[ModelStateType]
    Status: NotRequired[DeploymentStatusType]
    StatusReason: NotRequired[str]
    RollbackFailureReason: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class GetDeploymentsRequestRequestTypeDef(TypedDict):
    DeviceName: str
    DeviceFleetName: str


class GetDeviceRegistrationRequestRequestTypeDef(TypedDict):
    DeviceName: str
    DeviceFleetName: str


class DefinitionTypeDef(TypedDict):
    ModelHandle: NotRequired[str]
    S3Url: NotRequired[str]
    Checksum: NotRequired[ChecksumTypeDef]
    State: NotRequired[ModelStateType]


class DeploymentResultTypeDef(TypedDict):
    DeploymentName: NotRequired[str]
    DeploymentStatus: NotRequired[str]
    DeploymentStatusMessage: NotRequired[str]
    DeploymentStartTime: NotRequired[TimestampTypeDef]
    DeploymentEndTime: NotRequired[TimestampTypeDef]
    DeploymentModels: NotRequired[Sequence[DeploymentModelTypeDef]]


class EdgeMetricTypeDef(TypedDict):
    Dimension: NotRequired[str]
    MetricName: NotRequired[str]
    Value: NotRequired[float]
    Timestamp: NotRequired[TimestampTypeDef]


class EmptyResponseMetadataTypeDef(TypedDict):
    ResponseMetadata: ResponseMetadataTypeDef


class GetDeviceRegistrationResultTypeDef(TypedDict):
    DeviceRegistration: str
    CacheTTL: str
    ResponseMetadata: ResponseMetadataTypeDef


EdgeDeploymentTypeDef = TypedDict(
    "EdgeDeploymentTypeDef",
    {
        "DeploymentName": NotRequired[str],
        "Type": NotRequired[Literal["Model"]],
        "FailureHandlingPolicy": NotRequired[FailureHandlingPolicyType],
        "Definitions": NotRequired[List[DefinitionTypeDef]],
    },
)


class ModelTypeDef(TypedDict):
    ModelName: NotRequired[str]
    ModelVersion: NotRequired[str]
    LatestSampleTime: NotRequired[TimestampTypeDef]
    LatestInference: NotRequired[TimestampTypeDef]
    ModelMetrics: NotRequired[Sequence[EdgeMetricTypeDef]]


class GetDeploymentsResultTypeDef(TypedDict):
    Deployments: List[EdgeDeploymentTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class SendHeartbeatRequestRequestTypeDef(TypedDict):
    AgentVersion: str
    DeviceName: str
    DeviceFleetName: str
    AgentMetrics: NotRequired[Sequence[EdgeMetricTypeDef]]
    Models: NotRequired[Sequence[ModelTypeDef]]
    DeploymentResult: NotRequired[DeploymentResultTypeDef]
